@@ -42,7 +42,11 @@ def test_listener_class():
     test_node.spin()
 
 
-if __name__ == '__main__':
+def main():
     cyber.init()
     test_listener_class()
     cyber.shutdown()
+
+
+if __name__ == '__main__':
+    main()
